@@ -6,13 +6,13 @@
 # something goes wrong if you don't import pcop first.
 # Have to do this till I find out why...
 import pcop
-import dcop
+import pydcop
 
-class ParrotObject(dcop.DCOPServerObject):
+class ParrotObject(pydcop.DCOPServerObject):
     """DCOP server object"""
     
     def __init__(self, id='parrot'):
-        dcop.DCOPServerObject.__init__(self, id)
+        pydcop.DCOPServerObject.__init__(self, id)
 
         # DCOP needs types, so we need to initialise the object with the methods that
         # it's going to provide.
@@ -35,7 +35,7 @@ class ParrotObject(dcop.DCOPServerObject):
         return "This parrot, %i months old, squawks: %s" % (self.parrot_age, what_to_squawk)
         
 
-appid = dcop.registerAs('petshop')
+appid = pydcop.registerAs('petshop')
 print "Server: %s starting" % appid
 
 parrot = ParrotObject()
@@ -43,6 +43,6 @@ another_parrot = ParrotObject('polly')
 
 # Enter event loop
 while 1:
-    dcop.processEvents()
+    pydcop.processEvents()
 
 
