@@ -1,14 +1,14 @@
 
 import pcop
-import dcop
+import pydcop
 
-app = dcop.anyAppCalled("kspread")
+app = pydcop.anyAppCalled("kspread")
 
 table = app.default.getViews()[0]
 
 table.setSelection( ( 2, 2, 4, 6 ) )
 
-rect = table.selection()
+table.setSelectionBgColor( (100, 100, 240) )
 print rect
 
 print "done"
