@@ -20,8 +20,8 @@ public class SimpleMailer extends KApplication{
         kdejava.initialize();
     }
     
-    public SimpleMailer(String [] argv,String name) {
-        super(argv,name);
+    public SimpleMailer() {
+        super();
         SimpleMailFrm mainWidget = new SimpleMailFrm(this);
         this.setMainWidget(mainWidget);
         mainWidget.show();
@@ -32,6 +32,8 @@ public class SimpleMailer extends KApplication{
      * Entry point for the program
      */
     public static void main(String [] argv) {
-        SimpleMailer mailClnt = new SimpleMailer(argv, "Simple Mailing Application");
+	KCmdLineArgs.init(argv, "simplemailer", "SimpleMailer", 
+				 "Simple Mailing Application", "0.1");
+        SimpleMailer mailClnt = new SimpleMailer();
     }
 }
