@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  */
 #include "global.h"
 #include <qapplication.h>
@@ -230,6 +230,8 @@ void CustomObjectImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
 	    object.put( exec, "insertItem", KJS::Object(obj) );
 	    obj = new CustomObjectImp( exec, QMenuDataRemoveItem, proxy );
 	    object.put( exec, "removeItem", KJS::Object(obj) );
+	    obj = new CustomObjectImp( exec, QMenuDataRemoveItem, proxy );
+	    object.put( exec, "insertSeparator", KJS::Object(obj) );
 	}
 
 	QHBox *hbox = dynamic_cast<QHBox *>( widget );
@@ -504,6 +506,10 @@ KJS::Value CustomObjectImp::call( KJS::ExecState *exec, KJS::Object &self, const
 		qmenuDataRemoveItem(exec, self, args );
 		return KJS::Boolean(true);
 		break;
+	case QMenuDataInsertSeparator:
+		qmenuDataInsertSeparator(exec, self, args );
+		return KJS::Boolean(true);
+		break;
 
   case ListViewTakeItem:
       return qlistViewTakeItem(exec, self, args );
@@ -1420,6 +1426,15 @@ void Bindings::CustomObjectImp::qmenuDataRemoveItem(KJS::ExecState *exec, KJS::O
     menu->removeItem(idx);
 }
 
+KJS::Value Bindings::CustomObjectImp::qmenuDataInsertSeparator(KJS::ExecState *exec, KJS::Object &, const KJS::List &args )
+{
+    QMenuData *menu = dynamic_cast<QMenuData *>( proxy->object() );
+    if( !menu )
+        return KJS::Boolean(false);
+    int idx = extractInt(exec, args, 0);
+    return KJS::Number( menu->insertSeparator(idx) );
+}
+
 } // namespace KJSEmbed::Bindings
 }// namespace KJSEmbed
 
