@@ -15,13 +15,13 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  */
 
 #ifndef KJSEMBEDFACTORY_H
 #define KJSEMBEDFACTORY_H
-
+#include "global.h"
 #include <qmap.h>
 #include <qdict.h>
 #include <qstringlist.h>
@@ -44,8 +44,11 @@ namespace KParts {
  */
 namespace KJSEmbed {
 
-namespace Bindings { class JSFactoryImp;
-    class JSBindingPlugin; }
+namespace Bindings {
+    class JSFactoryImp;
+    class JSBindingPlugin;
+    class JSBindingBase;
+}
 
 class KJSEmbedPart;
 class JSEventMapper;
@@ -57,7 +60,7 @@ class JSObjectProxy;
  *
  * @author Richard Moore, rich@kde.org
  */
-class JSFactory
+class KJSEMBED_EXPORT JSFactory
 {
 public:
     /**
@@ -106,7 +109,45 @@ public:
     /** Creates a proxy object for the specified target with the specified context. */
     KJS::Object createProxy( KJS::ExecState *exec, QEvent *target,
 			     const JSObjectProxy *context ) const;
+    
+    
+    /**
+    * Registers an opaque proxy factory with the with the factory.
+    * To add an opaque type to the system you need to provide a factory based off of @ref KJSEmbed::Bindings::JSBindingBase
+     */
+    void registerOpaqueType( const QString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
 
+    /**
+    * Remove an opaque type from the system.
+     */
+    void unregisterOpaqueType( const QString &className );
+
+    /**
+     * When passed an object for a type handled by an Opaque proxy this method
+     * will add the bindings for that opaque object to the proxy.  If the object
+     * is not supported it is unmodified.
+     */
+    void extendOpaqueProxy( KJS::ExecState *exec, KJS::Object &proxy) const;
+
+    /**
+    * Registers a QObject proxy factory with the with the factory.
+    * To add an opaque type to the system you need to provide a factory based off of @ref KJSEmbed::Bindings::JSBindingBase
+     */
+    void registerObjectType( const QString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
+
+    /**
+    * Remove an opaque type from the system.
+     */
+    void unregisterObjectType( const QString &className );
+
+    /**
+     * When passed an object for a type handled by an Opaque proxy this method
+     * will add the bindings for that opaque object to the proxy.  If the object
+     * is not supported it is unmodified.
+     */
+    void extendObjectProxy( KJS::ExecState *exec, KJS::Object &proxy) const;
+
+    
     //
     // Methods for creating custom objects.
     //
@@ -164,7 +205,7 @@ public:
     QWidget *loadUI( const QString &uiFile, QObject *connector=0, QWidget *parent=0, const char *name=0 );
 
     /**
-    * Queries KTrader for a plugin that provides the asked for object binding. 
+    * Queries KTrader for a plugin that provides the asked for object binding.
     *If the binding was added the object is returned, otherwise a KJS::Null is.
     */
     QStringList listBindingPlugins( KJS::ExecState *exec, KJS::Object &self);
@@ -231,11 +272,11 @@ public:
     void addTypes( KJS::ExecState *exec, KJS::Object &parent );
 
     QStringList types() const;
-    
+
 protected:
     /** Adds custom bindings to the specified proxy object. */
     KJS::Object extendProxy( KJS::ExecState *exec, KJS::Object &target ) const;
-    
+
     /** Creates an instance of the named class and returns it in a JSValueProxy. */
     KJS::Object createValue( KJS::ExecState *exec, const QString &cname, const KJS::List &args );
 
@@ -265,6 +306,7 @@ protected:
     QWidget *createWidget( const QString &cname, QWidget *parent, const char *name );
 
 private:
+    
     /** Adds the types defined by QWidgetFactory to the specified parent. */
     void addWidgetFactoryTypes( KJS::ExecState *exec, KJS::Object &parent );
 
@@ -274,7 +316,7 @@ private:
     /** Adds support for QObject binding types to the specified parent. */
     void addBindingTypes( KJS::ExecState *exec, KJS::Object &parent );
 
-    /** 
+    /**
      * Adds support for any QObject types that are known about, but have no
      * custom support (and no constructor).
      */
@@ -283,7 +325,7 @@ private:
     void addOpaqueTypes( KJS::ExecState *exec, KJS::Object &parent );
 
     void addValueTypes( KJS::ExecState *exec, KJS::Object &parent );
-    
+
 private:
     KJSEmbedPart *jspart;
     JSEventMapper *evmapper;
