@@ -1,5 +1,5 @@
 
-  
+
 
 #include <qcstring.h>
 #include <qpalette.h>
@@ -168,7 +168,7 @@ QComboBox *QComboBoxImp::toQComboBox( KJS::Object &self )
     if ( op->typeName() != "QComboBox" )
         return 0;
 
-    return (QComboBox *)( op->toVoidStar() );
+    return op->toNative<QComboBox>();
 }
 
 /**
@@ -181,61 +181,62 @@ KJS::Object QComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &args
          case Constructor_QComboBox_1:
              return QComboBox_1( exec, args );
              break;
-    
+
          case Constructor_QComboBox_2:
              return QComboBox_2( exec, args );
              break;
-    
+
          default:
              break;
     }
 
     QString msg = i18n("QComboBoxCons has no constructor with id '%1'.").arg(id);
-    KJS::Object err = KJS::Error::create( exec, KJS::ReferenceError, msg.utf8() );
-    exec->setException( err );
-    return err;
+    return throwError(exec, msg,KJS::ReferenceError);
 }
 
 
 KJS::Object QComboBoxImp::QComboBox_1( KJS::ExecState *exec, const KJS::List &args )
 {
-#if 0    
+#if 0
     // Unsupported parameter QWidget *
     return KJS::Value();
-    
+
     QWidget * arg0; // Dummy
-        
+
     const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
-        
+
 
     // We should now create an object of type QComboBoxQComboBox *ret = new QComboBox(
-       
+
           arg0,
           arg1 );
 #endif
+return KJS::Object();
 }
-    
+
 KJS::Object QComboBoxImp::QComboBox_2( KJS::ExecState *exec, const KJS::List &args )
 {
-#if 0    
+#if 0
     bool arg0 = extractBool(exec, args, 0);
-        
+
     // Unsupported parameter QWidget *
     return KJS::Value();
-    
+
     QWidget * arg1; // Dummy
-        
+
     const char *arg2 = (args.size() >= 3) ? args[2].toString(exec).ascii() : 0;
-        
+
 
     // We should now create an object of type QComboBoxQComboBox *ret = new QComboBox(
-       
+
           arg0,
           arg1,
           arg2 );
 #endif
+return KJS::Object();
+
 }
-    
+
 KJS::Value QComboBoxImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
 {
     instance = QComboBoxImp::toQComboBox( self );
@@ -245,716 +246,714 @@ KJS::Value QComboBoxImp::call( KJS::ExecState *exec, KJS::Object &self, const KJ
     case Method_count_4:
         return count_4( exec, self, args );
         break;
-    
+
     case Method_insertStringList_5:
         return insertStringList_5( exec, self, args );
         break;
-    
+
     case Method_insertStrList_6:
         return insertStrList_6( exec, self, args );
         break;
-    
+
     case Method_insertStrList_7:
         return insertStrList_7( exec, self, args );
         break;
-    
+
     case Method_insertStrList_8:
         return insertStrList_8( exec, self, args );
         break;
-    
+
     case Method_insertItem_9:
         return insertItem_9( exec, self, args );
         break;
-    
+
     case Method_insertItem_10:
         return insertItem_10( exec, self, args );
         break;
-    
+
     case Method_insertItem_11:
         return insertItem_11( exec, self, args );
         break;
-    
+
     case Method_removeItem_12:
         return removeItem_12( exec, self, args );
         break;
-    
+
     case Method_currentItem_13:
         return currentItem_13( exec, self, args );
         break;
-    
+
     case Method_setCurrentItem_14:
         return setCurrentItem_14( exec, self, args );
         break;
-    
+
     case Method_currentText_15:
         return currentText_15( exec, self, args );
         break;
-    
+
     case Method_setCurrentText_16:
         return setCurrentText_16( exec, self, args );
         break;
-    
+
     case Method_text_17:
         return text_17( exec, self, args );
         break;
-    
+
     case Method_pixmap_18:
         return pixmap_18( exec, self, args );
         break;
-    
+
     case Method_changeItem_19:
         return changeItem_19( exec, self, args );
         break;
-    
+
     case Method_changeItem_20:
         return changeItem_20( exec, self, args );
         break;
-    
+
     case Method_changeItem_21:
         return changeItem_21( exec, self, args );
         break;
-    
+
     case Method_autoResize_22:
         return autoResize_22( exec, self, args );
         break;
-    
+
     case Method_setAutoResize_23:
         return setAutoResize_23( exec, self, args );
         break;
-    
+
     case Method_sizeHint_24:
         return sizeHint_24( exec, self, args );
         break;
-    
+
     case Method_setPalette_25:
         return setPalette_25( exec, self, args );
         break;
-    
+
     case Method_setFont_26:
         return setFont_26( exec, self, args );
         break;
-    
+
     case Method_setEnabled_27:
         return setEnabled_27( exec, self, args );
         break;
-    
+
     case Method_setSizeLimit_28:
         return setSizeLimit_28( exec, self, args );
         break;
-    
+
     case Method_sizeLimit_29:
         return sizeLimit_29( exec, self, args );
         break;
-    
+
     case Method_setMaxCount_30:
         return setMaxCount_30( exec, self, args );
         break;
-    
+
     case Method_maxCount_31:
         return maxCount_31( exec, self, args );
         break;
-    
+
     case Method_setInsertionPolicy_32:
         return setInsertionPolicy_32( exec, self, args );
         break;
-    
+
     case Method_insertionPolicy_33:
         return insertionPolicy_33( exec, self, args );
         break;
-    
+
     case Method_setValidator_34:
         return setValidator_34( exec, self, args );
         break;
-    
+
     case Method_validator_35:
         return validator_35( exec, self, args );
         break;
-    
+
     case Method_setListBox_36:
         return setListBox_36( exec, self, args );
         break;
-    
+
     case Method_listBox_37:
         return listBox_37( exec, self, args );
         break;
-    
+
     case Method_setLineEdit_38:
         return setLineEdit_38( exec, self, args );
         break;
-    
+
     case Method_lineEdit_39:
         return lineEdit_39( exec, self, args );
         break;
-    
+
     case Method_setAutoCompletion_40:
         return setAutoCompletion_40( exec, self, args );
         break;
-    
+
     case Method_autoCompletion_41:
         return autoCompletion_41( exec, self, args );
         break;
-    
+
     case Method_eventFilter_42:
         return eventFilter_42( exec, self, args );
         break;
-    
+
     case Method_setDuplicatesEnabled_43:
         return setDuplicatesEnabled_43( exec, self, args );
         break;
-    
+
     case Method_duplicatesEnabled_44:
         return duplicatesEnabled_44( exec, self, args );
         break;
-    
+
     case Method_editable_45:
         return editable_45( exec, self, args );
         break;
-    
+
     case Method_setEditable_46:
         return setEditable_46( exec, self, args );
         break;
-    
+
     case Method_popup_47:
         return popup_47( exec, self, args );
         break;
-    
+
     case Method_hide_48:
         return hide_48( exec, self, args );
         break;
-    
+
     default:
         break;
     }
 
     QString msg = i18n( "QComboBoxImp has no method with id '%1'." ).arg( id );
-    KJS::Object err = KJS::Error::create( exec, KJS::ReferenceError, msg.utf8() );
-    exec->setException( err );
-    return err;
+    return throwError(exec, msg,KJS::ReferenceError);
 }
 
 
 KJS::Value QComboBoxImp::count_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       int ret;
       ret = instance->count(  );
       return KJS::Number( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertStringList_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QStringList arg0 = extractQStringList(exec, args, 0);
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
-      instance->insertStringList( 
+
+      instance->insertStringList(
        arg0,
        arg1 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertStrList_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QStrList arg0 = extractQStrList(exec, args, 0);
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
-      instance->insertStrList( 
+
+      instance->insertStrList(
        arg0,
        arg1 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertStrList_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     // Unsupported parameter const QStrList *
     return KJS::Value();
-    
+
     const QStrList * arg0; // Dummy
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
-      instance->insertStrList( 
+
+      instance->insertStrList(
        arg0,
        arg1 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertStrList_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     // Unsupported parameter const char **
     return KJS::Value();
-    
+
     const char ** arg0; // Dummy
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
+
     int arg2 = extractInt(exec, args, 2);
-        
-      instance->insertStrList( 
+
+      instance->insertStrList(
        arg0,
        arg1,
        arg2 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertItem_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QString arg0 = extractQString(exec, args, 0);
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
-      instance->insertItem( 
+
+      instance->insertItem(
        arg0,
        arg1 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertItem_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QPixmap arg0 = extractQPixmap(exec, args, 0);
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
-      instance->insertItem( 
+
+      instance->insertItem(
        arg0,
        arg1 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertItem_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QPixmap arg0 = extractQPixmap(exec, args, 0);
-        
+
     QString arg1 = extractQString(exec, args, 1);
-        
+
     int arg2 = extractInt(exec, args, 2);
-        
-      instance->insertItem( 
+
+      instance->insertItem(
        arg0,
        arg1,
        arg2 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::removeItem_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     int arg0 = extractInt(exec, args, 0);
-        
-      instance->removeItem( 
+
+      instance->removeItem(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::currentItem_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       int ret;
       ret = instance->currentItem(  );
       return KJS::Number( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setCurrentItem_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     int arg0 = extractInt(exec, args, 0);
-        
-      instance->setCurrentItem( 
+
+      instance->setCurrentItem(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::currentText_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       QString ret;
       ret = instance->currentText(  );
       return KJS::String( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setCurrentText_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QString arg0 = extractQString(exec, args, 0);
-        
-      instance->setCurrentText( 
+
+      instance->setCurrentText(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::text_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     int arg0 = extractInt(exec, args, 0);
-        
+
       QString ret;
-      ret = instance->text( 
+      ret = instance->text(
        arg0 );
       return KJS::String( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::pixmap_18( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     int arg0 = extractInt(exec, args, 0);
-        
-      instance->pixmap( 
+
+      instance->pixmap(
        arg0 );
       return KJS::Value(); // Returns 'const QPixmap *'
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::changeItem_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QString arg0 = extractQString(exec, args, 0);
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
-      instance->changeItem( 
+
+      instance->changeItem(
        arg0,
        arg1 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::changeItem_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QPixmap arg0 = extractQPixmap(exec, args, 0);
-        
+
     int arg1 = extractInt(exec, args, 1);
-        
-      instance->changeItem( 
+
+      instance->changeItem(
        arg0,
        arg1 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::changeItem_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QPixmap arg0 = extractQPixmap(exec, args, 0);
-        
+
     QString arg1 = extractQString(exec, args, 1);
-        
+
     int arg2 = extractInt(exec, args, 2);
-        
-      instance->changeItem( 
+
+      instance->changeItem(
        arg0,
        arg1,
        arg2 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::autoResize_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       bool ret;
       ret = instance->autoResize(  );
       return KJS::Boolean( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setAutoResize_23( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     bool arg0 = extractBool(exec, args, 0);
-        
-      instance->setAutoResize( 
+
+      instance->setAutoResize(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::sizeHint_24( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
     QSize ret;
       ret = instance->sizeHint(  );
 
        return convertToValue( exec, ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setPalette_25( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QPalette arg0 = extractQPalette(exec, args, 0);
-        
-      instance->setPalette( 
+
+      instance->setPalette(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setFont_26( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     QFont arg0 = extractQFont(exec, args, 0);
-        
-      instance->setFont( 
+
+      instance->setFont(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setEnabled_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     bool arg0 = extractBool(exec, args, 0);
-        
-      instance->setEnabled( 
+
+      instance->setEnabled(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setSizeLimit_28( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     int arg0 = extractInt(exec, args, 0);
-        
-      instance->setSizeLimit( 
+
+      instance->setSizeLimit(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::sizeLimit_29( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       int ret;
       ret = instance->sizeLimit(  );
       return KJS::Number( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setMaxCount_30( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     int arg0 = extractInt(exec, args, 0);
-        
-      instance->setMaxCount( 
+
+      instance->setMaxCount(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::maxCount_31( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       int ret;
       ret = instance->maxCount(  );
       return KJS::Number( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setInsertionPolicy_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
-    QComboBox::Policy arg0; // TODO (hack for combo box)
-        
-      instance->setInsertionPolicy( 
+
+    QComboBox::Policy arg0 = QComboBox::AtBottom; // TODO (hack for combo box)
+
+      instance->setInsertionPolicy(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::insertionPolicy_33( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       instance->insertionPolicy(  );
       return KJS::Value(); // Returns 'Policy'
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setValidator_34( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     // Unsupported parameter const QValidator *
     return KJS::Value();
-    
+
     const QValidator * arg0; // Dummy
-        
-      instance->setValidator( 
+
+      instance->setValidator(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::validator_35( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       instance->validator(  );
       return KJS::Value(); // Returns 'const QValidator *'
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setListBox_36( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     // Unsupported parameter QListBox *
     return KJS::Value();
-    
+
     QListBox * arg0; // Dummy
-        
-      instance->setListBox( 
+
+      instance->setListBox(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::listBox_37( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       instance->listBox(  );
       return KJS::Value(); // Returns 'QListBox *'
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setLineEdit_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     // Unsupported parameter QLineEdit *
     return KJS::Value();
-    
+
     QLineEdit * arg0; // Dummy
-        
-      instance->setLineEdit( 
+
+      instance->setLineEdit(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::lineEdit_39( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       instance->lineEdit(  );
       return KJS::Value(); // Returns 'QLineEdit *'
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setAutoCompletion_40( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     bool arg0 = extractBool(exec, args, 0);
-        
-      instance->setAutoCompletion( 
+
+      instance->setAutoCompletion(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::autoCompletion_41( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       bool ret;
       ret = instance->autoCompletion(  );
       return KJS::Boolean( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::eventFilter_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     // Unsupported parameter QObject *
     return KJS::Value();
-    
+
     QObject * arg0; // Dummy
-        
+
     // Unsupported parameter QEvent *
     return KJS::Value();
-    
+
     QEvent * arg1; // Dummy
-        
+
       bool ret;
-      ret = instance->eventFilter( 
+      ret = instance->eventFilter(
        arg0,
        arg1 );
       return KJS::Boolean( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setDuplicatesEnabled_43( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     bool arg0 = extractBool(exec, args, 0);
-        
-      instance->setDuplicatesEnabled( 
+
+      instance->setDuplicatesEnabled(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::duplicatesEnabled_44( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       bool ret;
       ret = instance->duplicatesEnabled(  );
       return KJS::Boolean( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::editable_45( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       bool ret;
       ret = instance->editable(  );
       return KJS::Boolean( ret );
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::setEditable_46( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
     bool arg0 = extractBool(exec, args, 0);
-        
-      instance->setEditable( 
+
+      instance->setEditable(
        arg0 );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::popup_47( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       instance->popup(  );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 KJS::Value QComboBoxImp::hide_48( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    
+
       instance->hide(  );
       return KJS::Value(); // Returns void
-      
+
 }
-    
+
 
 } // namespace KJSEmbed
 
