@@ -1,4 +1,4 @@
-var h=new QHBox();
+var h=new QHBox(this);
 var combo = new QComboBox(h, "combo");
 combo.insertItem("Item 1");
 combo.insertItem("Item 2");
