@@ -211,7 +211,7 @@ module KDE
 				
 				# Get the functions() for this dcop ref and 
 				# cache method_name => full_type_signature in a hash
-				if @functions.nil?
+				if !defined(@functions) || @functions.nil?
 					@functions = {}
 					funcs = call("functions()")
 					if funcs.nil?
@@ -608,6 +608,10 @@ module KDE
 				it += 1
 			end
 		end
+
+		def sort(*args)
+			method_missing(:sort, *args)
+		end
 	end
 
 	class ListViewItem
@@ -621,6 +625,10 @@ module KDE
 			end
 		end
 
+		def sort(*args)
+			method_missing(:sort, *args)
+		end
+
 		def inspect
 			str = super
 			str.sub!(/>$/, "")
