@@ -18,19 +18,22 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef __kurifilter_h__
-#define __kurifilter_h__ "$Id: kurifilter.h 322023 2004-06-19 20:33:37Z sedwards $"
+#define __kurifilter_h__
 
 #include <qptrlist.h>
 #include <qobject.h>
 #include <qstringlist.h>
 
 #include <kurl.h>
-#include <kdemacros.h>
+
+#ifdef Q_OS_WIN
+#undef ERROR
+#endif
 
 class KURIFilterPrivate;
 class KURIFilterDataPrivate;
@@ -72,7 +75,7 @@ class KCModule;
 * @author Dawit Alemayehu <adawit at kde.org>
 */
 
-class KURIFilterData
+class KIO_EXPORT KURIFilterData
 {
 friend class KURIFilterPlugin;
 
@@ -338,7 +341,7 @@ private:
  *
  * @short Abstract class for URI filter plugins.
  */
-class KURIFilterPlugin : public QObject
+class KIO_EXPORT KURIFilterPlugin : public QObject
 {
     Q_OBJECT
 
@@ -437,7 +440,7 @@ private:
 /**
  * A list of filter plugins.
  */
-class KURIFilterPluginList : public QPtrList<KURIFilterPlugin>
+class KIO_EXPORT KURIFilterPluginList : public QPtrList<KURIFilterPlugin>
 {
 public:
     virtual int compareItems(Item a, Item b)
@@ -522,7 +525,7 @@ private:
  * @short Filters a given URL into its proper format whenever possible.
  */
 
-class KURIFilter
+class KIO_EXPORT KURIFilter
 {
 public:
     /**
