@@ -1,6 +1,6 @@
 # This script generates the PyQt configuration and generates the Makefiles.
 #
-# Copyright (c) 2004
+# Copyright (c) 2005
 # 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 # 
 # This file is part of PyQt.
@@ -17,7 +17,7 @@
 # 
 # You should have received a copy of the GNU General Public License along with
 # PyQt; see the file LICENSE.  If not, write to the Free Software Foundation,
-# Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
 import sys
@@ -32,11 +32,11 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x030d00
-pyqt_version_str = "3.13"
+pyqt_version = 0x030e01
+pyqt_version_str = "3.14.1"
 
-sip_min_v3_version = 0x030a02
-sip_min_v4_version = 0x040000
+sip_min_v3_version = 0x030c00
+sip_min_v4_version = 0x040200
 
 pyqt_modules = ["qt"]
 qt_sip_flags = []
@@ -72,6 +72,10 @@ opt_releasegil = 0
 opt_tracing = 0
 opt_verbose = 0
 
+opt_vendorcheck = 0
+opt_vendincdir = sipcfg.py_inc_dir
+opt_vendlibdir = sipcfg.py_lib_dir
+
 
 def usage(rcode = 2):
     """Display a usage message and exit.
@@ -79,16 +83,18 @@ def usage(rcode = 2):
     rcode is the return code passed back to the calling process.
     """
     print "Usage:"
-    print "    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-g] [-j #] [-k] [-n dir] [-o dir] [-r] [-s] [-t dir] [-u] [-v dir] [-w]"
+    print "    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-i] [-j #] [-k] [-l dir] [-m dir] [-n dir] [-o dir] [-r] [-s] [-u] [-v dir] [-w]"
     print "where:"
     print "    -h      display this help message"
     print "    -a tag  explicitly enable the qtpe module"
     print "    -b dir  where pyuic and pylupdate will be installed [default %s]" % opt_pyqtbindir
     print "    -c      concatenate each module's C/C++ source files"
     print "    -d dir  where the PyQt modules will be installed [default %s]" % opt_pyqtmoddir
-    print "    -g      always release the GIL (SIP v3.x behaviour)"
+    print "    -i      enable checking of signed interpreters using the VendorID package [default disabled]"
     print "    -j #    split the concatenated C++ source files into # pieces [default 1]"
     print "    -k      build the PyQt modules as static libraries"
+    print "    -l dir  the directory containing the VendorID header file [default %s]" % opt_vendincdir
+    print "    -m dir  the directory containing the VendorID library [default %s]" % opt_vendlibdir
     print "    -n dir  the directory containing the QScintilla header files [default %s]" % opt_qsciincdir
     print "    -o dir  the directory containing the QScintilla library [default %s]" % opt_qscilibdir
     print "    -r      generate code with tracing enabled [default disabled]"
@@ -116,6 +122,9 @@ def inform_user():
     if sipcfg.qt_version >= 0x030000:
         sipconfig.inform("pylupdate will be installed in %s." % opt_pyqtbindir)
 
+    if opt_vendorcheck:
+        sipconfig.inform("PyQt will only be usable with signed interpreters.")
+
 
 def create_config(module, template):
     """Create the PyQt configuration module so that it can be imported by build
@@ -186,6 +195,7 @@ def compile_qt_program(name, define=None, include_dir=None, lib_dir=None, lib=No
     lib is the name of a library to add to the list of libraries.
     opengl is set if the application uses OpenGL.
     python is set if the application #includes Python.h.
+    debug is set if this is a debug build.
 
     Returns the name of the executable suitable for running or None if it
     wasn't created.
@@ -267,6 +277,23 @@ def check_qscintilla():
         sipconfig.inform("qextscintillaglobal.h could not be found in %s and so the qtext module will not be built. If QScintilla is installed then use the -n argument to explicitly specify the correct directory." % opt_qsciincdir)
 
 
+def check_vendorid():
+    """See if the VendorID library and include file can be found.
+    """
+    global opt_vendorcheck
+
+    if opt_vendorcheck:
+        if os.access(os.path.join(opt_vendincdir, "vendorid.h"), os.F_OK):
+            if glob.glob(os.path.join(opt_vendlibdir, "*vendorid*")):
+                sipconfig.inform("The VendorID package was found.")
+            else:
+                opt_vendorcheck = 0
+                sipconfig.inform("The VendorID library could not be found in %s and so signed interpreter checking will be disabled. If the VendorID library is installed then use the -m argument to explicitly specify the correct directory." % opt_vendlibdir)
+        else:
+            opt_vendorcheck = 0
+            sipconfig.inform("vendorid.h could not be found in %s and so signed interpreter checking will be disabled. If the VendorID package is installed then use the -l argument to explicitly specify the correct directory." % opt_vendincdir)
+
+
 def check_module(mname, incfile, ctor, define=None, include_dir=None, lib_dir=None, lib=None, opengl=0):
     """See if a module can be built and, if so, add it to the global list of
     modules.
@@ -468,6 +495,12 @@ def set_sip_flags():
     # Handle the features.
     qt_sip_flags.extend(get_feature_flags())
 
+    # If we don't check for signed interpreters, we exclude the 'VendorID'
+    # feature
+    if not opt_vendorcheck:
+        qt_sip_flags.append("-x")
+        qt_sip_flags.append("VendorID")
+
     # Handle the platform tag.
     if opt_qtpetag:
         plattag = "WS_QWS"
@@ -517,7 +550,8 @@ def set_sip_flags():
             0x010200: "QScintilla_1_1",
             0x010300: "QScintilla_1_2",
             0x010400: "QScintilla_1_3",
-            0x020000: "QScintilla_1_4"
+            0x010500: "QScintilla_1_4",
+            0x020000: "QScintilla_1_5"
         }
 
         qtext_sip_flags.append("-t")
@@ -529,7 +563,7 @@ def set_sip_flags():
         qtpe_sip_flags.append(opt_qtpetag)
 
 
-def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, extra_define=None, extra_include_dir=None, extra_lflags=None, extra_lib_dir=None, extra_lib=None, opengl=0, sip_flags=None):
+def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, extra_define=None, extra_include_dir=None, extra_lflags=None, extra_lib_dir=None, extra_libs=None, opengl=0, sip_flags=None):
     """Generate the code for a module.
 
     mname is the name of the module.
@@ -542,7 +576,8 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
     extra_lflags is a string containing additional linker flags.
     extra_lib_dir is the name of a directory to add to the list of library
     directories.
-    extra_lib is the name of an extra library to add to the list of libraries.
+    extra_libs is a list of the names of extra libraries to add to the list of
+    libraries.
     opengl is set if the module needs OpenGL support.
     sip_flags is the list of sip flags to use instead of the defaults.
     """
@@ -559,7 +594,7 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
         sipconfig.error("Unable to create the %s directory." % mname)
 
     # Build the SIP command line.
-    argv = [sipcfg.sip_bin]
+    argv = ['"' + sipcfg.sip_bin + '"']
 
     if sip_flags is None:
         sip_flags = qt_sip_flags
@@ -651,8 +686,8 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
     if extra_lib_dir:
         makefile.extra_lib_dirs.append(extra_lib_dir)
 
-    if extra_lib:
-        makefile.extra_libs.append(extra_lib)
+    if extra_libs:
+        makefile.extra_libs.extend(extra_libs)
 
     if sipcfg.sip_version < 0x040000 and imports:
         # Inter-module links.
@@ -839,7 +874,7 @@ def main(argv):
     argv is the list of command line arguments.
     """
     try:
-        optlist, args = getopt.getopt(argv[1:], "ha:b:cd:gj:kn:o:rst:uv:w")
+        optlist, args = getopt.getopt(argv[1:], "ha:b:cd:gij:kln:o:rst:uv:w")
     except getopt.GetoptError:
         usage()
 
@@ -847,6 +882,7 @@ def main(argv):
     global opt_qtpetag, opt_static, opt_debug, opt_concat, opt_releasegil
     global opt_split, opt_tracing, opt_verbose
     global opt_qsciincdir, opt_qscilibdir, qsci_define
+    global opt_vendorcheck, opt_vendincdir, opt_vendlibdir
 
     for opt, arg in optlist:
         if opt == "-h":
@@ -854,13 +890,15 @@ def main(argv):
         elif opt == "-a":
             opt_qtpetag = arg
         elif opt == "-b":
-            opt_pyqtbindir = arg
+            opt_pyqtbindir = os.path.abspath(arg)
         elif opt == "-c":
             opt_concat = 1
         elif opt == "-d":
-            opt_pyqtmoddir = arg
+            opt_pyqtmoddir = os.path.abspath(arg)
         elif opt == "-g":
             opt_releasegil = 1
+        elif opt == "-i":
+            opt_vendorcheck = 1
         elif opt == "-j":
             try:
                 opt_split = int(arg)
@@ -868,6 +906,10 @@ def main(argv):
                 usage()
         elif opt == "-k":
             opt_static = 1
+        elif opt == "-l":
+            opt_vendincdir = arg
+        elif opt == "-m":
+            opt_vendlibdir = arg
         elif opt == "-n":
             opt_qsciincdir = arg
         elif opt == "-o":
@@ -881,13 +923,18 @@ def main(argv):
         elif opt == "-u":
             opt_debug = 1
         elif opt == "-v":
-            opt_pyqtsipdir = arg
+            opt_pyqtsipdir = os.path.abspath(arg)
         elif opt == "-w":
             opt_verbose = 1
 
     if args:
         usage()
 
+    # When building static libraries, signed interpreter checking makes no
+    # sense.
+    if opt_vendorcheck and opt_static:
+        sipconfig.error("Using the VendorID package when building static libraries make no sense.")
+
     check_license()
 
     sipconfig.inform("SIP %s is being used." % sipcfg.sip_version_str)
@@ -941,6 +988,9 @@ def main(argv):
         else:
             disabled_classes.append("QAssistantClient")
 
+    # Check for the VendorID package.
+    check_vendorid()
+
     # Set the SIP platform, version and feature flags.
     set_sip_flags()
 
@@ -955,25 +1005,39 @@ def main(argv):
         qtmod_lflags = ""
 
     # Generate the code.
-    generate_code("qt", extra_lflags=qtmod_lflags, extra_lib=qtmod_lib)
+
+    extra_libs = []
+
+    if qtmod_lib:
+        extra_libs.append(qtmod_lib)
+
+    if opt_vendorcheck:
+        extra_include_dir = opt_vendincdir
+        extra_lib_dir = opt_vendlibdir
+        extra_libs.append("vendorid")
+    else:
+        extra_include_dir = None
+        extra_lib_dir = None
+
+    generate_code("qt", extra_lflags=qtmod_lflags, extra_include_dir=extra_include_dir, extra_lib_dir=extra_lib_dir, extra_libs=extra_libs)
 
     if "qtext" in pyqt_modules:
-        generate_code("qtext", imports=["qt"], extra_define=qsci_define, extra_include_dir=opt_qsciincdir, extra_lib_dir=opt_qscilibdir, extra_lib="qscintilla", sip_flags=qtext_sip_flags)
+        generate_code("qtext", imports=["qt"], extra_define=qsci_define, extra_include_dir=opt_qsciincdir, extra_lib_dir=opt_qscilibdir, extra_libs=["qscintilla"], sip_flags=qtext_sip_flags)
 
     if "qtgl" in pyqt_modules:
         generate_code("qtgl", imports=["qt"], opengl=1)
 
     if "qtpe" in pyqt_modules:
-        generate_code("qtpe", imports=["qt"], extra_lib="qpe", sip_flags=qtpe_sip_flags)
+        generate_code("qtpe", imports=["qt"], extra_libs=["qpe"], sip_flags=qtpe_sip_flags)
 
     if "qtsql" in pyqt_modules:
         generate_code("qtsql", imports=["qt", "qttable"])
 
     if "qtui" in pyqt_modules:
-        generate_code("qtui", imports=["qt"], extra_lib="qui")
+        generate_code("qtui", imports=["qt"], extra_libs=["qui"])
 
     if "qtaxcontainer" in pyqt_modules:
-        generate_code("qtaxcontainer", imports=["qt"], extra_lib="qaxcontainer")
+        generate_code("qtaxcontainer", imports=["qt"], extra_libs=["qaxcontainer"])
 
     # The rest don't need special handling.
     for m in ("qtcanvas", "qtnetwork", "qttable", "qtxml"):
