@@ -122,6 +122,7 @@ void Uic::createFormImpl( const QDomElement &e )
     QStringList globalIncludes;
     QStringList::Iterator it;
     QStringList sqlClasses;
+    QStringList axwidgets, databrowsers;
 
     QMap<QString, CustomInclude> customWidgetIncludes;
     QMap<QString, QString> functionImpls;
@@ -206,8 +207,6 @@ void Uic::createFormImpl( const QDomElement &e )
 
                    if (pos > -1)
                    {  
-                        fprintf(stderr,"Extracting %s\n",rx.cap(1).latin1());
-
                         if (inFunction)
                             functionImpls.insert(Parser::cleanArgs(functionName),functionText);
 
@@ -234,8 +233,6 @@ void Uic::createFormImpl( const QDomElement &e )
     }
 
     // includes for child widgets
-    bool need_axwidget = FALSE;
-
     for ( it = tags.begin(); it != tags.end(); ++it ) {
 	nl = e.parentNode().toElement().elementsByTagName( *it );
 	for ( i = 1; i < (int) nl.length(); i++ ) { // start at 1, 0 is the toplevel widget
@@ -248,7 +245,9 @@ void Uic::createFormImpl( const QDomElement &e )
 	    if ( name.mid( 1 ) == "ListView" )
 		globalIncludes += "qheader.h";
 	    else if ( name == "QAxWidget" )
-		need_axwidget = TRUE;
+		axwidgets += getObjectName(nl.item(i).toElement());
+	    else if ( name == "QDataBrowser" )
+		databrowsers += getObjectName(nl.item(i).toElement());
 	    if ( name != objClass ) {
 		int wid = WidgetDatabase::idFromClassName( name );
 		QMap<QString, CustomInclude>::Iterator it = customWidgetIncludes.find( name );
@@ -261,9 +260,12 @@ void Uic::createFormImpl( const QDomElement &e )
     if (globalIncludes.findIndex("qtable.h") >= 0)
 	out << indent << "from qttable import QTable" << endl;
 
-    if (need_axwidget)
+    if (!axwidgets.empty())
 	out << indent << "from qtaxcontainer import QAxWidget" << endl;
 
+    if (globalIncludes.findIndex("qextscintilla.h") >= 0)
+	out << indent << "from qtext import QextScintilla" << endl;
+
     registerDatabases( e );
     dbConnections = unique( dbConnections );
     if ( dbConnections.count() )
@@ -296,6 +298,9 @@ void Uic::createFormImpl( const QDomElement &e )
     if (globalIncludes.findIndex("qdatabrowser.h") >= 0)
         sqlClasses += "QDataBrowser";
 
+    if (globalIncludes.findIndex("qdataview.h") >= 0)
+        sqlClasses += "QDataView";
+
     if ( !sqlClasses.empty() ) {
 	out << indent << "from qtsql import";
 	char *sep = " ";
@@ -641,29 +646,35 @@ void Uic::createFormImpl( const QDomElement &e )
 		    sender = "self";
 		else
 		    sender = "self." + sender;
+
+		bool isaxwidget = (axwidgets.findIndex(receiver) >= 0);
+		bool isdatabrowser = (databrowsers.findIndex(receiver) >= 0);
+
 		if ( receiver == objName )
 		    receiver = "self";
 		else
 		    receiver = "self." + receiver;
 
 		out << indent << "self.connect(" << sender
-		    << ",SIGNAL(\"" << signal << "\"),";
+		    << ",SIGNAL(\"" << signal << "\")," << receiver;
 
-		// See if this is a user defined slot.
-		bool isUserSlot = FALSE;
-		for (it = extraSlots.begin(); it != extraSlots.end(); ++it) {
-		    if (*it == slot) {
-			isUserSlot = TRUE;
-			break;
-		    }
+		// Normally we never use the SLOT() macro in case the
+		// connection is to a method of a Python custom widget.  The
+		// exception is if the receiver is a QAxWidget where it must be
+		// used because the slots are dynamic.
+		if (isaxwidget)
+		    out << ",SLOT(\"" << slot << "\")";
+		else
+		{
+		    QString mname = slot.left(slot.find('('));
+
+		    // Rename slots that have different names in PyQt.
+		    if (isdatabrowser && mname == "del")
+			    mname = "delOnCursor";
+
+		    out << "." << mname;
 		}
- 
-		if (isUserSlot) {
-		    out << "self." << slot.left(slot.find('('));
-		} else {
-		    out << receiver << ",SLOT(\"" << slot << "\")";
-		}
- 
+
 		out << ")" << endl;
 	    }
 	} else if ( n.tagName()  == "tabstops" ) {
